@@ -1,12 +1,12 @@
 use utf8;
 use strict;
 
+use XML::Pastor::Builtin::Scalar;
+use MIME::Base64 ();
+
 
 #======================================================================
 package XML::Pastor::Builtin::base64Binary;
-use XML::Pastor::Builtin::Scalar;
-use MIME::Base64 ();
-
 our @ISA = qw(XML::Pastor::Builtin::Scalar);
 
 XML::Pastor::Builtin::base64Binary->XmlSchemaType( bless( {
@@ -22,14 +22,14 @@ XML::Pastor::Builtin::base64Binary->XmlSchemaType( bless( {
 #-----------------------------------------------------------------
 sub toBinary {
 	my $self  = shift;
-	my $value = $self->__value() . "";	
+	my $value = $self->value() . "";	
 	return MIME::Base64::decode($value)
 }
 
 #-----------------------------------------------------------------
 sub setFromBinary($$) {
 	my $self  = shift;
-	return $self->__value(MIME::Base64::encode($_[0], ''));
+	return $self->value(MIME::Base64::encode($_[0], ''));
 }
 
 #-----------------------------------------------------------------
